package
Version:
v0.0.0-...-839d480
Opens a new window with list of versions in this module.
Published: Apr 20, 2022
License: BSD-3-Clause
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
micro/ctxkey
ctxkey provides a user-defined context key (see go doc context.WithValue).
Documentation
package ctxkey // import "bitbucket.org/_mikey/micro/ctxkey"
Package ctxkey
TYPES
type Key string
Key is a user-defined context key (context.WithValue(ctx, NewKey("my-key"),
value))
func NewKey(k string) Key
NewKey returns a new Key
Documentation
¶
Key is a user-defined context key (context.WithValue(ctx, NewKey("my-key"), value))
Source Files
¶
Click to show internal directories.
Click to hide internal directories.